<?php

/**
 * @plugin    Awo Email Login
 * @copyright Copyright (C) 2010 Seyi Awofadeju - All rights reserved.
 * @Website   : http://dev.awofadeju.com
 * @license   - http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * */
defined('_JEXEC') or die;

JLoader::register('CustomGithubProvider', dirname(__FILE__) . '/CustomGithubProvider.php');

class plgAuthenticationGithub extends JPlugin
{
	/**
	 * Authenticate user using Github login
	 *
	 * @param                         $credentials
	 * @param                         $options
	 * @param JAuthenticationResponse $response
	 *
	 *
	 * @since 1.0
	 */
	public function onUserAuthenticate($credentials, $options, &$response)
	{
		$app = JFactory::getApplication();

		if ($app->isSite() && $app->input->getCmd('auth') === 'github')
		{
			$code           = $app->input->get->getString('code');
			$githubProvider = $this->getGithubProvider();

			$accessToken = $githubProvider->getAccessToken('authorization_code', array('code' => $code));

			if (!empty($accessToken))
			{
				try
				{
					$userData = $githubProvider->getResourceOwner($accessToken);
					CclHelpersCcl::logInUser('github', $userData->getId(), $userData->getName(), $githubProvider->getEmail($accessToken), $response);
				}
				catch (Exception $e)
				{
					$response->status        = JAuthentication::STATUS_FAILURE;
					$response->error_message = $e->getMessage();
				}
			}
			else
			{
				$response->status = JAuthentication::STATUS_CANCEL;
			}
		}
	}


	public function onAuthenticationMethodRender()
	{
		$provider = $this->getGithubProvider();
		$options  = array(
			'state' => 'OPTIONAL_CUSTOM_CONFIGURED_STATE',
			'scope' => array('user', 'user:email')
		);

		return
			(object) array(
				'url'    => $provider->getAuthorizationUrl($options),
				'plugin' => 'github'
			);
	}

	/**
	 * Get github provider
	 *
	 * @return CustomGithubProvider
	 *
	 * @since version
	 */
	public function getGithubProvider()
	{
		$provider = new CustomGithubProvider(array(
			'clientId'     => $this->params->get('client_id'),
			'clientSecret' => $this->params->get('client_secret'),
			'redirectUri'  => CclHelpersCcl::getLoginUrl('github')
		));

		return $provider;
	}
}